==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/english/original_sections/checkout/checkout_payment.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	checkout_payment.lang.inc.php 2018-02-13
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'heading_payment'                  => 'Payment method',
    'text_accept_agb'                  => 'I accept your general business conditions',
    'text_accept_transport_conditions' => 'I agree',
    'text_accept_withdrawal'           => 'I accept your right of withdrawal conditions',
    'text_address'                     => 'Please choose the required billing address for your order from your address book.',
    'text_agb'                         => 'Please accept our general business conditions',
    'text_comments'                    => 'Insert your comments on this order here',
    'text_comments_placeholder'        => 'Insert your comments on this order here',
    'text_confirm'                     => 'Confirm',
    'text_continue'                    => 'to your order confirmation',
    'text_finished'                    => 'Done!',
    'text_gccover'                     => 'Your coupon covers the total amount of your order, please accept our general business and supply conditions and proceed to the ordering procedure',
    'text_payment'                     => 'Please choose the required mode of payment for your order.',
    'text_payment_info'                => 'Payment method',
    'text_ship'                        => 'Shipping',
    'text_pay'                         => 'Payment',
    'text_shipping_info'               => 'Shipping informationen',
    'text_shoppingcart'                => 'Cart',
    'text_transport_conditions'        => 'Please give your consent.',
    'text_withdrawal'                  => 'I accept your right of withdrawal conditions',
    'text_yourdata'                    => 'Your data',
    'title_address'                    => 'Billing postal address',
    'title_agb'                        => 'General business conditions',
    'title_comments'                   => 'Insert personal memo relating to your order',
    'title_continue'                   => 'Continue the ordering procedure',
    'title_payment'                    => 'Payment method',
    'title_transport_conditions'       => 'Data transfer to carriers',
    'title_shipping_company'           => 'Shipping company',
    'title_withdrawal'                 => 'Right of Withdrawal'
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/english/original_sections/checkout/checkout_payment.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	checkout_payment.lang.inc.php 2018-02-13
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'heading_payment'                  => 'Payment method',
    'text_accept_agb'                  => 'I accept your general business conditions',
    'text_accept_transport_conditions' => 'I agree',
    'text_accept_withdrawal'           => 'I accept your right of withdrawal conditions',
    'text_address'                     => 'Please choose the required billing address for your order from your address book.',
    'text_agb'                         => 'Please accept our general business conditions',
    'text_comments'                    => 'Insert your comments on this order here',
    'text_comments_placeholder'        => 'Insert your comments on this order here',
    'text_confirm'                     => 'Confirm',
    'text_continue'                    => 'to your order confirmation',
    'text_finished'                    => 'Done!',
    'text_focover'                     => 'Your order is free of charge.',
    'text_gccover'                     => 'Your coupon covers the total amount of your order, please accept our general business and supply conditions and proceed to the ordering procedure.',
    'text_payment'                     => 'Please choose the required mode of payment for your order.',
    'text_payment_info'                => 'Payment method',
    'text_ship'                        => 'Shipping',
    'text_pay'                         => 'Payment',
    'text_shipping_info'               => 'Shipping informationen',
    'text_shoppingcart'                => 'Cart',
    'text_transport_conditions'        => 'Please give your consent.',
    'text_withdrawal'                  => 'I accept your right of withdrawal conditions',
    'text_yourdata'                    => 'Your data',
    'title_address'                    => 'Billing postal address',
    'title_agb'                        => 'General business conditions',
    'title_comments'                   => 'Insert personal memo relating to your order',
    'title_continue'                   => 'Continue the ordering procedure',
    'title_payment'                    => 'Payment method',
    'title_transport_conditions'       => 'Data transfer to carriers',
    'title_shipping_company'           => 'Shipping company',
    'title_withdrawal'                 => 'Right of Withdrawal'
];
